import{a as e,A as t,B as i}from"./Title.ac2baa04.js";import{A as d}from"./Link.8c5f038e.js";import{a as o,A as r}from"./Text.03e848c4.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="91b8df64-3e8f-44d9-83ab-ad7d682d8eeb",n._sentryDebugIdIdentifier="sentry-dbid-91b8df64-3e8f-44d9-83ab-ad7d682d8eeb")}catch{}})();e.Text=o;e.Title=t;e.Paragraph=r;e.Link=d;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,o),n.component(e.Title.displayName,t),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,d),n};
//# sourceMappingURL=index.e44c4190.js.map
