import{d as u,eB as b,G as f,b as y,c as g,u as _}from"./outputWidgets.e33755f8.js";import{a as w}from"./asyncComputed.8bd4aeca.js";import"./authorManager.62b862f9.js";import"./index.0a6756f7.js";import{M as m}from"./member.e4e6430b.js";import{C as I}from"./CrudView.2f0c3c83.js";import"./index.cf4c23b9.js";import"./record.fe2d13ca.js";import"./pubsub.d8fbcc91.js";import"./gateway.f3da19f9.js";import"./icons.f6b19bc0.js";import"./Text.03e848c4.js";import"./Title.ac2baa04.js";import"./FormItem.fdb358e6.js";import"./hasIn.5c4a4bf3.js";import"./Form.e78b9235.js";import"./Modal.e934f1f6.js";import"./router.8c7b3fad.js";import"./index.9f6d3055.js";import"./url.3d250afc.js";import"./index.98828044.js";import"./index.58a4a13c.js";import"./index.4b06b554.js";import"./index.72b0b8fe.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="04faa8f0-3e0b-472a-b522-16770cb89296",e._sentryDebugIdIdentifier="sentry-dbid-04faa8f0-3e0b-472a-b522-16770cb89296")}catch{}})();const Q=u({__name:"Members",setup(e){const r=b().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),d()},{loading:l,result:p,refetch:d}=w(()=>m.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=p.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{Q as default};
//# sourceMappingURL=Members.eeff7987.js.map
