import{d as h,eA as y,eB as k,r as w,G as x,b as n,c as l,w as t,ev as b,eC as I,u as d,bf as C,ez as f,f as s,I as B,aq as N,eD as S,bq as D,bh as V,v as A,eE as L,eF as E,e as g,a as _,ex as T}from"./outputWidgets.e33755f8.js";import{h as q,c as P,m as $,p as z}from"./icons.f6b19bc0.js";import{_ as F}from"./logo.084e5d7c.js";import{B as H}from"./BaseLayout.f64f85ae.js";import{N as M}from"./NavbarControls.054f8239.js";import{c as R}from"./index.68c8be46.js";import"./workspaces.b0dc20eb.js";import"./record.fe2d13ca.js";import"./pubsub.d8fbcc91.js";import"./url.3d250afc.js";import"./popupNotifcation.74287a31.js";import"./asyncComputed.8bd4aeca.js";import"./index.6f9fba0f.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.31d93ab7.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.8a8a9b35.js";import"./ant-design.4ca18c4d.js";import"./index.7be3845f.js";import"./Modal.e934f1f6.js";import"./index.4b06b554.js";import"./Text.03e848c4.js";import"./Title.ac2baa04.js";import"./index.e44c4190.js";import"./Link.8c5f038e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="603075d2-c66b-41e7-9284-e2da92aec17e",e._sentryDebugIdIdentifier="sentry-dbid-603075d2-c66b-41e7-9284-e2da92aec17e")}catch{}})();const W=h({__name:"Sidebar",setup(e){var m;const o=y(),c=k(),r=w((m=c.name)!=null?m:"forms"),u=x(()=>[{name:"Home",icon:q,path:"home"},{name:"Style settings",icon:P,path:"style"},{name:"Sidebar settings",icon:$,path:"sidebar"},{name:"Python Packages",icon:z,path:"requirements"}]),i=p=>{o.push(p.path),r.value=p.path};return(p,X)=>(n(),l(d(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),b(D,null,I(u.value,a=>(n(),l(d(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:Y=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(S(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const G={},v=e=>(L("data-v-81cd596e"),e=e(),E(),e),j={class:"logo"},J=v(()=>g("img",{src:F,alt:"Abstra cloud logo"},null,-1)),K=v(()=>g("span",null," Abstra ",-1)),O=[J,K];function Q(e,o){return n(),b("div",j,O)}const U=A(G,[["render",Q],["__scopeId","data-v-81cd596e"]]),we=h({__name:"Workspace",setup(e){return(o,c)=>{const r=_("ant-button"),u=_("router-link"),i=_("router-view");return n(),l(H,null,{navbar:t(()=>[s(d(R),{style:{padding:"5px 25px"}},{title:t(()=>[s(U)]),extra:t(()=>[s(M,{"show-github-stars":""},{default:t(()=>[T("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(W,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{we as default};
//# sourceMappingURL=Workspace.71b7a5b4.js.map
