import"./outputWidgets.e33755f8.js";import"./index.7be3845f.js";import{M as n}from"./Modal.e934f1f6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="4eb8c68d-b192-4f34-9f17-3285e198c6d5",t._sentryDebugIdIdentifier="sentry-dbid-4eb8c68d-b192-4f34-9f17-3285e198c6d5")}catch{}})();function f(t){switch(typeof t){case"object":return Object.entries(t).map(([e,r])=>({title:e,key:e,children:f(r)}));default:return[{title:t,key:t}]}}function i(t,e){return new Promise(r=>{n.confirm({title:t,onOk:()=>r(!0),okText:e==null?void 0:e.okText,onCancel:()=>r(!1),cancelText:e==null?void 0:e.cancelText})})}export{i as a,f as t};
//# sourceMappingURL=ant-design.4ca18c4d.js.map
