import{cw as r}from"./outputWidgets.e33755f8.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="1d190a45-3b4b-49df-a578-43bbdcadf58f",d._sentryDebugIdIdentifier="sentry-dbid-1d190a45-3b4b-49df-a578-43bbdcadf58f")}catch{}})();const o=(d,e)=>{r.error({message:d,description:e})};export{o as p};
//# sourceMappingURL=popupNotifcation.74287a31.js.map
