import{_ as C}from"./logo.084e5d7c.js";import{v as I,b as r,ev as y,eE as B,eF as w,e as h,d as k,eA as L,a as D,u as e,c,bg as S,w as t,f as o,aq as l,eD as i,bO as b,cC as f,cy as N,eK as V,eC as E,f3 as R,bq as q,ex as F}from"./outputWidgets.e33755f8.js";import{a as g}from"./authorManager.62b862f9.js";import{a as P}from"./asyncComputed.8bd4aeca.js";import{a as T}from"./Text.03e848c4.js";import{A as $,B as j,a as H,c as K}from"./index.68c8be46.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="6fece25a-bebe-40d1-bb18-e23abb8ee499",a._sentryDebugIdIdentifier="sentry-dbid-6fece25a-bebe-40d1-bb18-e23abb8ee499")}catch{}})();const M={},v=a=>(B("data-v-439be421"),a=a(),w(),a),O={class:"logo"},U=v(()=>h("img",{class:"logo-img",src:C,alt:"Abstra cloud logo"},null,-1)),z=v(()=>h("span",null,"Abstra Cloud",-1)),G=[U,z];function J(a,s){return r(),y("div",O,G)}const Q=I(M,[["render",J],["__scopeId","data-v-439be421"]]),W=k({__name:"LoginBlock",setup(a){function s(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(_=>_[0]).join("")}const u=L(),{result:n,loading:d,refetch:x}=P(async()=>g.getAuthor());function A(){g.removeAuthor(),x(),u.push({name:"login"})}return(p,m)=>{const _=D("router-link");return e(d)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(f),{direction:"vertical"},{default:t(()=>[o(e(T),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),o(e(b),{onClick:A},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(f),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e($),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(b),{key:2},{default:t(()=>[o(_,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),oe=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,u)=>(r(),c(e(K),{style:{padding:"5px 25px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(j),{key:0},{default:t(()=>[(r(!0),y(q,null,E(s.breadcrumb,(n,d)=>(r(),c(e(H),{key:d},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[o(Q)]),extra:t(()=>[o(W)]),_:1}))}});export{oe as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.71d1cd3f.js.map
