import{v as t,b as s,ev as o}from"./outputWidgets.e33755f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d45fbe7b-0716-40d4-9640-ca13cc88eb40",e._sentryDebugIdIdentifier="sentry-dbid-d45fbe7b-0716-40d4-9640-ca13cc88eb40")}catch{}})();const r={},c={class:"organization-settings"};function d(e,n){return s(),o("div",c,"Organization settings")}const f=t(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.a44ff231.js.map
