import{d as k,eB as B,eA as I,G as w,a as h,b as o,c as d,w as a,eJ as j,f as n,u as t,ev as c,eC as x,aq as g,eD as z,bq as C,ex as D,bg as A,cC as S}from"./outputWidgets.e33755f8.js";import{B as $}from"./BaseLayout.f64f85ae.js";import{a as M}from"./asyncComputed.8bd4aeca.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.aefe65df.js";import"./authorManager.62b862f9.js";import{a as P}from"./build.09dae85c.js";import"./index.0a6756f7.js";import{P as R}from"./project.8cd2a0dc.js";import{O as V}from"./organization.a0d50745.js";import{B as q,a as E,c as L}from"./index.68c8be46.js";import{a as O}from"./Text.03e848c4.js";import"./gateway.f3da19f9.js";import"./WarningFilled.d99917ef.js";import"./log.285a992d.js";import"./ant-design.4ca18c4d.js";import"./index.7be3845f.js";import"./Modal.e934f1f6.js";import"./index.9d5de84e.js";import"./Link.8c5f038e.js";import"./Title.ac2baa04.js";import"./index.9f6d3055.js";import"./TabPane.46e3ba1c.js";import"./hasIn.5c4a4bf3.js";import"./index.a9453f8b.js";import"./isNumeric.75337b1e.js";import"./icons.f6b19bc0.js";import"./index.8036b935.js";import"./FormItem.fdb358e6.js";import"./index.cf4c23b9.js";import"./record.fe2d13ca.js";import"./pubsub.d8fbcc91.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="70dd6797-4bb0-41cb-bcac-188242e78859",i._sentryDebugIdIdentifier="sentry-dbid-70dd6797-4bb0-41cb-bcac-188242e78859")}catch{}})();const T={key:0},F={key:2},Bt=k({__name:"Build",setup(i){const s=B(),l=I(),m=s.params.buildId,{result:e,loading:b}=M(async()=>{const r=await P.get(m),p=await R.get(r.projectId),u=await V.get(p.organizationId);return j({bs:r,project:p,organization:u})}),f=w(()=>!b.value&&e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.organization.name,path:`/organizations/${e.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${e.value.project.id}/builds`}]:void 0);function y(){var r;(r=e.value)!=null&&r.project.id&&l.push({name:"builds",params:{projectId:e.value.project.id}})}return(r,p)=>{const u=h("router-link");return o(),d($,null,{navbar:a(()=>[n(t(L),{title:"Inspect Build",style:{padding:"5px 25px"},onBack:y},{breadcrumb:a(()=>[f.value?(o(),d(t(q),{key:0},{default:a(()=>[(o(!0),c(C,null,x(f.value,(_,v)=>(o(),d(t(E),{key:v},{default:a(()=>[n(u,{to:_.path},{default:a(()=>[g(z(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),_:1})]),content:a(()=>[t(b)?(o(),c("div",T,[n(t(A))])):t(e)?(o(),d(N,{key:1,"build-spec":t(e).bs},null,8,["build-spec"])):(o(),c("div",F,[n(t(S),{direction:"vertical"},{default:a(()=>[n(t(O),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{Bt as default};
//# sourceMappingURL=Build.cc5011bd.js.map
