import{d,eB as g,G as l,a as b,b as f,c as v,w as r,f as s}from"./outputWidgets.e33755f8.js";import{B as _}from"./BaseLayout.f64f85ae.js";import{a as h}from"./asyncComputed.8bd4aeca.js";import"./authorManager.62b862f9.js";import"./index.0a6756f7.js";import{P as y}from"./project.8cd2a0dc.js";import{O as z}from"./organization.a0d50745.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.71d1cd3f.js";import{_ as I}from"./Sidebar.vue_vue_type_script_setup_true_lang.1ef44c32.js";import{B as w,H as B,I as k,J as $,K as P,L as C,u as D,M as L,N as M,D as x,E as O,F as E}from"./icons.f6b19bc0.js";import"./index.cf4c23b9.js";import"./record.fe2d13ca.js";import"./pubsub.d8fbcc91.js";import"./gateway.f3da19f9.js";import"./logo.084e5d7c.js";import"./Text.03e848c4.js";import"./Title.ac2baa04.js";import"./index.68c8be46.js";import"./index.98828044.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="55eaafe9-4592-4519-8c7e-45e2a25777e1",o._sentryDebugIdIdentifier="sentry-dbid-55eaafe9-4592-4519-8c7e-45e2a25777e1")}catch{}})();const ea=d({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),m=l(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=l(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:B},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:$},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:C},{name:"Files",path:"files",icon:D},{name:"Logs",icon:L,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:E,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ea as default};
//# sourceMappingURL=Project.eb88c181.js.map
