import"./outputWidgets.e33755f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="43bc7c6c-e61a-46f7-9e7e-d0846f327600",e._sentryDebugIdIdentifier="sentry-dbid-43bc7c6c-e61a-46f7-9e7e-d0846f327600")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.3d250afc.js.map
