import"./outputWidgets.e33755f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4ef72971-a680-4702-a3c3-0e55320777bb",e._sentryDebugIdIdentifier="sentry-dbid-4ef72971-a680-4702-a3c3-0e55320777bb")}catch{}})();function d(e,n,r=!1){const o=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_"),t=r?o:o.replace(/_+/g,"_");return n?t:t.replace(/_$/,"")}export{d as n};
//# sourceMappingURL=string.c37cf2a8.js.map
