import{_ as c}from"./Sidebar.vue_vue_type_script_setup_true_lang.1ef44c32.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.71d1cd3f.js";import{D as d,E as l,F as u}from"./icons.f6b19bc0.js";import{d as b,eB as f,G as _,a as g,b as y,c as v,w as t,f as r}from"./outputWidgets.e33755f8.js";import{a as w}from"./asyncComputed.8bd4aeca.js";import"./authorManager.62b862f9.js";import"./index.0a6756f7.js";import{O as z}from"./organization.a0d50745.js";import{B as h}from"./BaseLayout.f64f85ae.js";import"./index.98828044.js";import"./logo.084e5d7c.js";import"./Text.03e848c4.js";import"./Title.ac2baa04.js";import"./index.68c8be46.js";import"./index.cf4c23b9.js";import"./record.fe2d13ca.js";import"./pubsub.d8fbcc91.js";import"./gateway.f3da19f9.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[o]="34e4abb1-5323-445d-affa-14d0fc9c1203",a._sentryDebugIdIdentifier="sentry-dbid-34e4abb1-5323-445d-affa-14d0fc9c1203")}catch{}})();const A=b({__name:"Organization",setup(a){const n=f().params.organizationId,{result:e}=w(()=>z.get(n)),i=_(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=g("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{A as default};
//# sourceMappingURL=Organization.2e98fa4d.js.map
